package com.ruoyi.tcZz.controller;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.tcZz.domain.TcDbxt;
import com.ruoyi.tcZz.domain.TcDtsx;
import com.ruoyi.tcZz.domain.TcWljg;
import com.ruoyi.tcZz.service.ITcDtsxService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 动态筛选Controller
 *
 * @author ruoyi
 * @date 2023-10-12
 */
@RestController
@Api(tags = "动态筛选")
@RequestMapping("/tcZz/netWorkYq/dtsx")
public class TcDtsxController extends BaseController {
    @Autowired
    private ITcDtsxService tcDtsxService;

    /**
     * 查询动态筛选列表
     */
    @ApiOperation(value = "查询动态筛选列表",response = TcDtsx.class)
    @GetMapping("/list")
    public TableDataInfo list(TcDtsx tcDtsx) {
        startPage();
        List<TcDtsx> list = tcDtsxService.selectTcDtsxList(tcDtsx);
        return getDataTable(list);
    }

    /**
     * 导出动态筛选列表
     */
    @ApiOperation(value = "导出动态筛选列表")
    @PostMapping("/export")
    public void export(HttpServletResponse response, TcDtsx tcDtsx) {
        List<TcDtsx> list = tcDtsxService.selectTcDtsxList(tcDtsx);
        ExcelUtil<TcDtsx> util = new ExcelUtil<TcDtsx>(TcDtsx.class);
        util.exportExcel(response, list, "动态筛选数据");
    }

    /**
     * 获取动态筛选详细信息
     */
    @ApiOperation(value = "获取动态筛选详细信息")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(tcDtsxService.selectTcDtsxById(id));
    }

    /**
     * 新增动态筛选
     */
    @ApiOperation(value = "新增动态筛选")
    @PostMapping
    public AjaxResult add(@RequestBody TcDtsx tcDtsx) {
        return toAjax(tcDtsxService.insertTcDtsx(tcDtsx));
    }

    /**
     * 修改动态筛选
     */
    @ApiOperation(value = "修改动态筛选")
    @PutMapping
    public AjaxResult edit(@RequestBody TcDtsx tcDtsx) {
        return toAjax(tcDtsxService.updateTcDtsx(tcDtsx));
    }

    /**
     * 删除动态筛选
     */
    @ApiOperation(value = "删除动态筛选")
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(tcDtsxService.deleteTcDtsxByIds(ids));
    }
    /**
     * 导入
     */
    @ApiOperation("通用导入excel信息")
    @PostMapping("/common/importExcel")
    public AjaxResult importExcel(MultipartFile file) throws Exception {
        ExcelUtil<TcDtsx> util = new ExcelUtil<TcDtsx>(TcDtsx.class);
        List<TcDtsx> tcDtsxList = util.importExcel(file.getInputStream());
        tcDtsxService.importUser(tcDtsxList);
        return AjaxResult.success();
    }

    /**
     * 批量启用禁用
     *
     * @param isStatus 启用禁用状态
     * @return
     */

    @ApiOperation("批量启用禁用")
    @GetMapping("/isStatus")
    public AjaxResult isStatus(@RequestParam("isStatus") Integer isStatus, @RequestParam("ids") List<String> ids) {
        tcDtsxService.updateByisStatus(isStatus,ids);
        return AjaxResult.success();
    }

    @ApiOperation("通用下载excel模板")
    @PostMapping("/importTemplate")
    public void importTemplate(HttpServletResponse response)
    {
        ExcelUtil<TcDtsx> util = new ExcelUtil<TcDtsx>(TcDtsx.class);
        util.importTemplateExcel(response, " 动态筛选");
    }
}
